

### <a name="manual"></a> Title block

Inserts headings.

| Key       |      Description      | Default    |
|:----------|:--------------------- |:-----------|
| type      |  title              |
| title     |  title of the chapter | No title |
| level     |  (optional) title hierarchy level (0,1,2,3,...) | 0 |

Example:
```YAML
- type    : title
  level   : 0
  title   : Some Title
```

Back to [Documentation](../../../README.md#block_basic)
